@@ -314,7 +314,7 @@ class BaseDataConfig(collections.abc.MutableMapping):
             from .cryptography import CryptHandle
 
             self.__change_list[key] = True
-            self.__config[key] = CryptHandle(salt=self.__salt_key, alias=key, private=private)
+            self.__config[key] = CryptHandle(alias=key, private=private)
 
             if val:
                 self.__config[key].encrypt(val)
